CVSROOT: /home/cvs
Module name: linux
Changes by: ppopov@ftp.linux-mips.org 05/02/03 06:35:30
Modified files:
arch/mips : Tag: linux_2_4 defconfig-db1000
defconfig-db1100 defconfig-db1500
defconfig-db1550 defconfig-ficmmp
defconfig-pb1000 defconfig-pb1100
defconfig-pb1500 defconfig-pb1550
arch/mips/au1000/ficmmp: Tag: linux_2_4 au1200_ibutton.c
drivers/mtd/maps: Tag: linux_2_4 db1x00-flash.c
drivers/net/irda: Tag: linux_2_4 au1k_ir.c
drivers/pcmcia : Tag: linux_2_4 Makefile au1000_db1x00.c
Log message:
Db/Pb 1200 pcmcia support, updated defconfigs, minor fixes.
diff -urN linux/arch/mips/defconfig-db1000 linux/arch/mips/defconfig-db1000
--- linux/arch/mips/Attic/defconfig-db1000 2005/01/30 08:01:26 1.1.2.55
+++ linux/arch/mips/Attic/defconfig-db1000 2005/02/03 06:35:29 1.1.2.56
@@ -22,16 +22,19 @@
#
# CONFIG_ACER_PICA_61 is not set
# CONFIG_MIPS_BOSPORUS is not set
+# CONFIG_MIPS_FICMMP is not set
# CONFIG_MIPS_MIRAGE is not set
CONFIG_MIPS_DB1000=y
# CONFIG_MIPS_DB1100 is not set
# CONFIG_MIPS_DB1500 is not set
# CONFIG_MIPS_DB1550 is not set
+# CONFIG_MIPS_DB1200 is not set
# CONFIG_MIPS_PB1000 is not set
# CONFIG_MIPS_PB1100 is not set
# CONFIG_MIPS_PB1500 is not set
-# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_PB1550 is not set
+# CONFIG_MIPS_PB1200 is not set
+# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_XXS1500 is not set
# CONFIG_MIPS_MTX1 is not set
# CONFIG_COGENT_CSB250 is not set
@@ -926,7 +929,7 @@
# CONFIG_USB_UHCI is not set
# CONFIG_USB_UHCI_ALT is not set
CONFIG_USB_OHCI=y
-CONFIG_USB_NON_PCI_OHCI=y
+
#
# USB Device Class drivers
#
diff -urN linux/arch/mips/defconfig-db1100 linux/arch/mips/defconfig-db1100
--- linux/arch/mips/Attic/defconfig-db1100 2005/01/30 08:01:26 1.1.2.46
+++ linux/arch/mips/Attic/defconfig-db1100 2005/02/03 06:35:29 1.1.2.47
@@ -22,16 +22,19 @@
#
# CONFIG_ACER_PICA_61 is not set
# CONFIG_MIPS_BOSPORUS is not set
+# CONFIG_MIPS_FICMMP is not set
# CONFIG_MIPS_MIRAGE is not set
# CONFIG_MIPS_DB1000 is not set
CONFIG_MIPS_DB1100=y
# CONFIG_MIPS_DB1500 is not set
# CONFIG_MIPS_DB1550 is not set
+# CONFIG_MIPS_DB1200 is not set
# CONFIG_MIPS_PB1000 is not set
# CONFIG_MIPS_PB1100 is not set
# CONFIG_MIPS_PB1500 is not set
-# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_PB1550 is not set
+# CONFIG_MIPS_PB1200 is not set
+# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_XXS1500 is not set
# CONFIG_MIPS_MTX1 is not set
# CONFIG_COGENT_CSB250 is not set
@@ -967,7 +970,7 @@
# CONFIG_USB_UHCI is not set
# CONFIG_USB_UHCI_ALT is not set
CONFIG_USB_OHCI=y
-CONFIG_USB_NON_PCI_OHCI=y
+
#
# USB Device Class drivers
#
diff -urN linux/arch/mips/defconfig-db1500 linux/arch/mips/defconfig-db1500
--- linux/arch/mips/Attic/defconfig-db1500 2005/01/30 08:01:26 1.1.2.59
+++ linux/arch/mips/Attic/defconfig-db1500 2005/02/03 06:35:29 1.1.2.60
@@ -22,16 +22,19 @@
#
# CONFIG_ACER_PICA_61 is not set
# CONFIG_MIPS_BOSPORUS is not set
+# CONFIG_MIPS_FICMMP is not set
# CONFIG_MIPS_MIRAGE is not set
# CONFIG_MIPS_DB1000 is not set
# CONFIG_MIPS_DB1100 is not set
CONFIG_MIPS_DB1500=y
# CONFIG_MIPS_DB1550 is not set
+# CONFIG_MIPS_DB1200 is not set
# CONFIG_MIPS_PB1000 is not set
# CONFIG_MIPS_PB1100 is not set
# CONFIG_MIPS_PB1500 is not set
-# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_PB1550 is not set
+# CONFIG_MIPS_PB1200 is not set
+# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_XXS1500 is not set
# CONFIG_MIPS_MTX1 is not set
# CONFIG_COGENT_CSB250 is not set
@@ -802,7 +805,7 @@
# CONFIG_USB_UHCI is not set
# CONFIG_USB_UHCI_ALT is not set
CONFIG_USB_OHCI=y
-CONFIG_USB_NON_PCI_OHCI=y
+
#
# USB Device Class drivers
#
diff -urN linux/arch/mips/defconfig-db1550 linux/arch/mips/defconfig-db1550
--- linux/arch/mips/Attic/defconfig-db1550 2005/01/30 08:01:26 1.1.2.13
+++ linux/arch/mips/Attic/defconfig-db1550 2005/02/03 06:35:29 1.1.2.14
@@ -22,16 +22,19 @@
#
# CONFIG_ACER_PICA_61 is not set
# CONFIG_MIPS_BOSPORUS is not set
+# CONFIG_MIPS_FICMMP is not set
# CONFIG_MIPS_MIRAGE is not set
# CONFIG_MIPS_DB1000 is not set
# CONFIG_MIPS_DB1100 is not set
# CONFIG_MIPS_DB1500 is not set
CONFIG_MIPS_DB1550=y
+# CONFIG_MIPS_DB1200 is not set
# CONFIG_MIPS_PB1000 is not set
# CONFIG_MIPS_PB1100 is not set
# CONFIG_MIPS_PB1500 is not set
-# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_PB1550 is not set
+# CONFIG_MIPS_PB1200 is not set
+# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_XXS1500 is not set
# CONFIG_MIPS_MTX1 is not set
# CONFIG_COGENT_CSB250 is not set
@@ -883,7 +886,6 @@
# CONFIG_FB_ATY128 is not set
# CONFIG_FB_INTEL is not set
# CONFIG_FB_SIS is not set
-CONFIG_FB_SMI501=y
# CONFIG_FB_NEOMAGIC is not set
# CONFIG_FB_3DFX is not set
# CONFIG_FB_VOODOO1 is not set
@@ -965,7 +967,7 @@
# CONFIG_USB_UHCI is not set
# CONFIG_USB_UHCI_ALT is not set
CONFIG_USB_OHCI=y
-CONFIG_USB_NON_PCI_OHCI=y
+
#
# USB Device Class drivers
#
diff -urN linux/arch/mips/defconfig-ficmmp linux/arch/mips/defconfig-ficmmp
--- linux/arch/mips/Attic/defconfig-ficmmp 2005/01/30 08:01:26 1.1.2.1
+++ linux/arch/mips/Attic/defconfig-ficmmp 2005/02/03 06:35:29 1.1.2.2
@@ -1,5 +1,5 @@
#
-# Automatically generated by make menuconfig: don't edit
+# Automatically generated make config: don't edit
#
CONFIG_MIPS=y
CONFIG_MIPS32=y
@@ -36,7 +36,6 @@
# CONFIG_MIPS_PB1200 is not set
# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_XXS1500 is not set
-# CONFIG_MIPS_EP1000 is not set
# CONFIG_MIPS_MTX1 is not set
# CONFIG_COGENT_CSB250 is not set
# CONFIG_BAGET_MIPS is not set
@@ -59,6 +58,7 @@
# CONFIG_MOMENCO_OCELOT_C is not set
# CONFIG_MOMENCO_JAGUAR_ATX is not set
# CONFIG_PMC_BIG_SUR is not set
+# CONFIG_PMC_STRETCH is not set
# CONFIG_PMC_YOSEMITE is not set
# CONFIG_DDB5074 is not set
# CONFIG_DDB5476 is not set
@@ -122,6 +122,7 @@
# General setup
#
CONFIG_CPU_LITTLE_ENDIAN=y
+# CONFIG_BUILD_ELF64 is not set
CONFIG_NET=y
# CONFIG_PCI is not set
# CONFIG_PCI_NEW is not set
@@ -178,6 +179,7 @@
# CONFIG_CISS_MONITOR_THREAD is not set
# CONFIG_BLK_DEV_DAC960 is not set
# CONFIG_BLK_DEV_UMEM is not set
+# CONFIG_BLK_DEV_SX8 is not set
CONFIG_BLK_DEV_LOOP=y
# CONFIG_BLK_DEV_NBD is not set
# CONFIG_BLK_DEV_RAM is not set
@@ -240,13 +242,12 @@
# CONFIG_IP_SCTP is not set
# CONFIG_ATM is not set
# CONFIG_VLAN_8021Q is not set
-# CONFIG_IPX is not set
-# CONFIG_ATALK is not set
#
-# Appletalk devices
+#
#
-# CONFIG_DEV_APPLETALK is not set
+# CONFIG_IPX is not set
+# CONFIG_ATALK is not set
# CONFIG_DECNET is not set
# CONFIG_BRIDGE is not set
# CONFIG_X25 is not set
@@ -284,18 +285,27 @@
# IDE, ATA and ATAPI Block devices
#
CONFIG_BLK_DEV_IDE=y
+
+#
+# Please see Documentation/ide.txt for help/info on IDE drives
+#
CONFIG_BLK_DEV_HD_IDE=y
CONFIG_BLK_DEV_HD=y
+# CONFIG_BLK_DEV_IDE_SATA is not set
CONFIG_BLK_DEV_IDEDISK=y
CONFIG_IDEDISK_MULTI_MODE=y
CONFIG_IDEDISK_STROKE=y
# CONFIG_BLK_DEV_IDECS is not set
+# CONFIG_BLK_DEV_DELKIN is not set
# CONFIG_BLK_DEV_IDECD is not set
# CONFIG_BLK_DEV_IDETAPE is not set
# CONFIG_BLK_DEV_IDEFLOPPY is not set
# CONFIG_BLK_DEV_IDESCSI is not set
# CONFIG_IDE_TASK_IOCTL is not set
-CONFIG_BLK_DEV_IDE_AU1XXX=y
+
+#
+# IDE chipset support/bugfixes
+#
# CONFIG_BLK_DEV_CMD640 is not set
# CONFIG_BLK_DEV_CMD640_ENHANCED is not set
# CONFIG_BLK_DEV_ISAPNP is not set
@@ -312,6 +322,10 @@
# SCSI support
#
CONFIG_SCSI=y
+
+#
+# SCSI support type (disk, tape, CD-ROM)
+#
CONFIG_BLK_DEV_SD=y
CONFIG_SD_EXTRA_DEVS=40
CONFIG_CHR_DEV_ST=y
@@ -320,6 +334,10 @@
# CONFIG_BLK_DEV_SR_VENDOR is not set
CONFIG_SR_EXTRA_DEVS=2
# CONFIG_CHR_DEV_SG is not set
+
+#
+# Some SCSI devices (e.g. CD jukebox) support multiple LUNs
+#
# CONFIG_SCSI_DEBUG_QUEUES is not set
# CONFIG_SCSI_MULTI_LUN is not set
CONFIG_SCSI_CONSTANTS=y
@@ -343,6 +361,18 @@
# CONFIG_SCSI_AM53C974 is not set
# CONFIG_SCSI_MEGARAID is not set
# CONFIG_SCSI_MEGARAID2 is not set
+# CONFIG_SCSI_SATA is not set
+# CONFIG_SCSI_SATA_AHCI is not set
+# CONFIG_SCSI_SATA_SVW is not set
+# CONFIG_SCSI_ATA_PIIX is not set
+# CONFIG_SCSI_SATA_NV is not set
+# CONFIG_SCSI_SATA_PROMISE is not set
+# CONFIG_SCSI_SATA_SX4 is not set
+# CONFIG_SCSI_SATA_SIL is not set
+# CONFIG_SCSI_SATA_SIS is not set
+# CONFIG_SCSI_SATA_ULI is not set
+# CONFIG_SCSI_SATA_VIA is not set
+# CONFIG_SCSI_SATA_VITESSE is not set
# CONFIG_SCSI_BUSLOGIC is not set
# CONFIG_SCSI_DMX3191D is not set
# CONFIG_SCSI_DTC3280 is not set
@@ -397,7 +427,6 @@
#
CONFIG_NET_ETHERNET=y
# CONFIG_MIPS_AU1X00_ENET is not set
-CONFIG_AU1XXX_SMC91111=m
# CONFIG_SUNLANCE is not set
# CONFIG_SUNBMAC is not set
# CONFIG_SUNQE is not set
@@ -508,6 +537,7 @@
# CONFIG_AU1X00_USB_TTY is not set
# CONFIG_AU1X00_USB_RAW is not set
# CONFIG_TXX927_SERIAL is not set
+# CONFIG_MIPS_HYDROGEN3_BUTTONS is not set
CONFIG_UNIX98_PTYS=y
CONFIG_UNIX98_PTY_COUNT=256
@@ -518,7 +548,6 @@
# CONFIG_I2C_ALGOBIT is not set
# CONFIG_SCx200_ACB is not set
# CONFIG_I2C_ALGOPCF is not set
-CONFIG_I2C_ALGO_AU1550=y
# CONFIG_I2C_CHARDEV is not set
# CONFIG_I2C_PROC is not set
@@ -539,6 +568,10 @@
# CONFIG_INPUT_EMU10K1 is not set
# CONFIG_INPUT_SERIO is not set
# CONFIG_INPUT_SERPORT is not set
+
+#
+# Joysticks
+#
# CONFIG_INPUT_ANALOG is not set
# CONFIG_INPUT_A3D is not set
# CONFIG_INPUT_ADI is not set
@@ -590,12 +623,6 @@
# CONFIG_DRM is not set
# CONFIG_AU1X00_GPIO is not set
# CONFIG_TS_AU1X00_ADS7846 is not set
-# CONFIG_AU1550_PSC_SPI is not set
-# CONFIG_AU1XXX_MAE is not set
-# CONFIG_AU1XXX_AES is not set
-# CONFIG_AU1XXX_CIM is not set
-# CONFIG_AU1XXX_AES_TEST is not set
-# CONFIG_AU1XXX_BUTTONS is not set
#
# File systems
@@ -752,9 +779,6 @@
CONFIG_FB=y
CONFIG_DUMMY_CONSOLE=y
# CONFIG_FB_CYBER2000 is not set
-CONFIG_FB_AU1200=y
-CONFIG_FB_AU1200_DEVS=4
-CONFIG_FOCUS_ENHANCEMENTS=y
# CONFIG_FB_VIRTUAL is not set
CONFIG_FBCON_ADVANCED=y
# CONFIG_FBCON_MFB is not set
@@ -805,7 +829,7 @@
# CONFIG_SOUND_SONICVIBES is not set
# CONFIG_SOUND_AU1X00 is not set
# CONFIG_SOUND_AU1550_PSC is not set
-CONFIG_SOUND_AU1550_I2S=y
+# CONFIG_SOUND_AU1550_I2S is not set
# CONFIG_SOUND_TRIDENT is not set
# CONFIG_SOUND_MSNDCLAS is not set
# CONFIG_SOUND_MSNDPIN is not set
@@ -832,12 +856,6 @@
# CONFIG_BLUEZ is not set
#
-# MMC/SD Card support
-#
-# CONFIG_MMC is not set
-# CONFIG_MMC_AU1100 is not set
-
-#
# Kernel hacking
#
CONFIG_CROSSCOMPILE=y
diff -urN linux/arch/mips/defconfig-pb1000 linux/arch/mips/defconfig-pb1000
--- linux/arch/mips/Attic/defconfig-pb1000 2005/01/30 08:01:26
1.29.2.88
+++ linux/arch/mips/Attic/defconfig-pb1000 2005/02/03 06:35:29
1.29.2.89
@@ -705,7 +705,7 @@
#
# CONFIG_PCMCIA_SERIAL_CS is not set
# CONFIG_SYNCLINK_CS is not set
-CONFIG_AU1X00_GPIO=m
+CONFIG_AU1X00_GPIO=y
# CONFIG_TS_AU1X00_ADS7846 is not set
#
diff -urN linux/arch/mips/defconfig-pb1100 linux/arch/mips/defconfig-pb1100
--- linux/arch/mips/Attic/defconfig-pb1100 2005/01/30 08:01:26 1.1.2.68
+++ linux/arch/mips/Attic/defconfig-pb1100 2005/02/03 06:35:29 1.1.2.69
@@ -22,16 +22,19 @@
#
# CONFIG_ACER_PICA_61 is not set
# CONFIG_MIPS_BOSPORUS is not set
+# CONFIG_MIPS_FICMMP is not set
# CONFIG_MIPS_MIRAGE is not set
# CONFIG_MIPS_DB1000 is not set
# CONFIG_MIPS_DB1100 is not set
# CONFIG_MIPS_DB1500 is not set
# CONFIG_MIPS_DB1550 is not set
+# CONFIG_MIPS_DB1200 is not set
# CONFIG_MIPS_PB1000 is not set
CONFIG_MIPS_PB1100=y
# CONFIG_MIPS_PB1500 is not set
-# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_PB1550 is not set
+# CONFIG_MIPS_PB1200 is not set
+# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_XXS1500 is not set
# CONFIG_MIPS_MTX1 is not set
# CONFIG_COGENT_CSB250 is not set
@@ -942,7 +945,7 @@
# CONFIG_USB_UHCI is not set
# CONFIG_USB_UHCI_ALT is not set
CONFIG_USB_OHCI=y
-CONFIG_USB_NON_PCI_OHCI=y
+
#
# USB Device Class drivers
#
diff -urN linux/arch/mips/defconfig-pb1500 linux/arch/mips/defconfig-pb1500
--- linux/arch/mips/Attic/defconfig-pb1500 2005/01/30 08:01:27 1.1.2.78
+++ linux/arch/mips/Attic/defconfig-pb1500 2005/02/03 06:35:29 1.1.2.79
@@ -22,16 +22,19 @@
#
# CONFIG_ACER_PICA_61 is not set
# CONFIG_MIPS_BOSPORUS is not set
+# CONFIG_MIPS_FICMMP is not set
# CONFIG_MIPS_MIRAGE is not set
# CONFIG_MIPS_DB1000 is not set
# CONFIG_MIPS_DB1100 is not set
# CONFIG_MIPS_DB1500 is not set
# CONFIG_MIPS_DB1550 is not set
+# CONFIG_MIPS_DB1200 is not set
# CONFIG_MIPS_PB1000 is not set
# CONFIG_MIPS_PB1100 is not set
CONFIG_MIPS_PB1500=y
-# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_PB1550 is not set
+# CONFIG_MIPS_PB1200 is not set
+# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_XXS1500 is not set
# CONFIG_MIPS_MTX1 is not set
# CONFIG_COGENT_CSB250 is not set
@@ -928,7 +931,6 @@
# CONFIG_FB_ATY128 is not set
# CONFIG_FB_INTEL is not set
# CONFIG_FB_SIS is not set
-CONFIG_FB_SMI501=y
# CONFIG_FB_NEOMAGIC is not set
# CONFIG_FB_3DFX is not set
# CONFIG_FB_VOODOO1 is not set
@@ -1012,7 +1014,7 @@
# CONFIG_USB_UHCI is not set
# CONFIG_USB_UHCI_ALT is not set
CONFIG_USB_OHCI=y
-CONFIG_USB_NON_PCI_OHCI=y
+
#
# USB Device Class drivers
#
diff -urN linux/arch/mips/defconfig-pb1550 linux/arch/mips/defconfig-pb1550
--- linux/arch/mips/Attic/defconfig-pb1550 2005/01/30 08:01:27 1.1.2.19
+++ linux/arch/mips/Attic/defconfig-pb1550 2005/02/03 06:35:29 1.1.2.20
@@ -22,16 +22,19 @@
#
# CONFIG_ACER_PICA_61 is not set
# CONFIG_MIPS_BOSPORUS is not set
+# CONFIG_MIPS_FICMMP is not set
# CONFIG_MIPS_MIRAGE is not set
# CONFIG_MIPS_DB1000 is not set
# CONFIG_MIPS_DB1100 is not set
# CONFIG_MIPS_DB1500 is not set
# CONFIG_MIPS_DB1550 is not set
+# CONFIG_MIPS_DB1200 is not set
# CONFIG_MIPS_PB1000 is not set
# CONFIG_MIPS_PB1100 is not set
# CONFIG_MIPS_PB1500 is not set
-# CONFIG_MIPS_HYDROGEN3 is not set
CONFIG_MIPS_PB1550=y
+# CONFIG_MIPS_PB1200 is not set
+# CONFIG_MIPS_HYDROGEN3 is not set
# CONFIG_MIPS_XXS1500 is not set
# CONFIG_MIPS_MTX1 is not set
# CONFIG_COGENT_CSB250 is not set
@@ -883,7 +886,6 @@
# CONFIG_FB_ATY128 is not set
# CONFIG_FB_INTEL is not set
# CONFIG_FB_SIS is not set
-CONFIG_FB_SMI501=y
# CONFIG_FB_NEOMAGIC is not set
# CONFIG_FB_3DFX is not set
# CONFIG_FB_VOODOO1 is not set
@@ -965,7 +967,7 @@
# CONFIG_USB_UHCI is not set
# CONFIG_USB_UHCI_ALT is not set
CONFIG_USB_OHCI=y
-CONFIG_USB_NON_PCI_OHCI=y
+
#
# USB Device Class drivers
#
diff -urN linux/arch/mips/au1000/ficmmp/au1200_ibutton.c
linux/arch/mips/au1000/ficmmp/au1200_ibutton.c
--- linux/arch/mips/au1000/ficmmp/Attic/au1200_ibutton.c 2005/01/30
08:01:27 1.1.2.1
+++ linux/arch/mips/au1000/ficmmp/Attic/au1200_ibutton.c 2005/02/03
06:35:29 1.1.2.2
@@ -210,7 +210,7 @@
/* register all button irq handler */
- for(i=0; i< izeof(button_map)/sizeof(button_map[0]); i++)
+ for(i=0; i< sizeof(button_map)/sizeof(button_map[0]); i++)
{
/* register irq <-- gpio 1 ,6 ,12 , 17 ,19 , 26 ,28 */
if(button_map[i] != 0)
diff -urN linux/drivers/mtd/maps/db1x00-flash.c
linux/drivers/mtd/maps/db1x00-flash.c
--- linux/drivers/mtd/maps/db1x00-flash.c 2003/02/16 06:25:24 1.1.2.1
+++ linux/drivers/mtd/maps/db1x00-flash.c 2005/02/03 06:35:29 1.1.2.2
@@ -28,8 +28,6 @@
static unsigned long window_size;
static unsigned long flash_size;
-static BCSR * const bcsr = (BCSR *)0xAE000000;
-
__u8 physmap_read8(struct map_info *map, unsigned long ofs)
{
__u8 ret;
diff -urN linux/drivers/net/irda/au1k_ir.c linux/drivers/net/irda/au1k_ir.c
--- linux/drivers/net/irda/au1k_ir.c 2003/07/09 20:05:55 1.2.2.5
+++ linux/drivers/net/irda/au1k_ir.c 2005/02/03 06:35:29 1.2.2.6
@@ -81,10 +81,6 @@
#define RUN_AT(x) (jiffies + (x))
-#if defined(CONFIG_MIPS_DB1000) || defined(CONFIG_MIPS_DB1100)
-static BCSR * const bcsr = (BCSR *)0xAE000000;
-#endif
-
static spinlock_t ir_lock = SPIN_LOCK_UNLOCKED;
/*
diff -urN linux/drivers/pcmcia/Makefile linux/drivers/pcmcia/Makefile
--- linux/drivers/pcmcia/Makefile 2004/04/16 21:05:25 1.12.2.12
+++ linux/drivers/pcmcia/Makefile 2005/02/03 06:35:30 1.12.2.13
@@ -64,11 +64,13 @@
au1000_ss-objs-$(CONFIG_MIPS_PB1000) += au1000_pb1x00.o
au1000_ss-objs-$(CONFIG_MIPS_PB1100) += au1000_pb1x00.o
au1000_ss-objs-$(CONFIG_MIPS_PB1500) += au1000_pb1x00.o
+au1000_ss-objs-$(CONFIG_MIPS_PB1550) += au1000_pb1550.o
+au1000_ss-objs-$(CONFIG_MIPS_PB1200) += au1000_db1x00.o
au1000_ss-objs-$(CONFIG_MIPS_DB1000) += au1000_db1x00.o
au1000_ss-objs-$(CONFIG_MIPS_DB1100) += au1000_db1x00.o
au1000_ss-objs-$(CONFIG_MIPS_DB1500) += au1000_db1x00.o
au1000_ss-objs-$(CONFIG_MIPS_DB1550) += au1000_db1x00.o
-au1000_ss-objs-$(CONFIG_MIPS_PB1550) += au1000_pb1550.o
+au1000_ss-objs-$(CONFIG_MIPS_DB1200) += au1000_db1x00.o
au1000_ss-objs-$(CONFIG_MIPS_HYDROGEN3) += au1000_hydrogen3.o
au1000_ss-objs-$(CONFIG_MIPS_XXS1500) += au1000_xxs1500.o
diff -urN linux/drivers/pcmcia/au1000_db1x00.c
linux/drivers/pcmcia/au1000_db1x00.c
--- linux/drivers/pcmcia/au1000_db1x00.c 2004/04/14 18:37:16 1.1.2.4
+++ linux/drivers/pcmcia/au1000_db1x00.c 2005/02/03 06:35:30 1.1.2.5
@@ -1,6 +1,6 @@
/*
*
* Alchemy Semi Db1x00 boards specific pcmcia routines.
*
* Copyright 2002 MontaVista Software Inc.
* Author: MontaVista Software, Inc.
@@ -54,9 +54,20 @@
#include <asm/au1000.h>
#include <asm/au1000_pcmcia.h>
+#if defined(CONFIG_MIPS_PB1200)
+#include <asm/pb1200.h>
+#elif defined(CONFIG_MIPS_DB1200)
+#include <asm/db1200.h>
+#else
#include <asm/db1x00.h>
+#endif
-static BCSR * const bcsr = (BCSR *)BCSR_KSEG1_ADDR;
+#define PCMCIA_MAX_SOCK 1
+#define PCMCIA_NUM_SOCKS (PCMCIA_MAX_SOCK+1)
+
+/* VPP/VCC */
+#define SET_VCC_VPP(VCC, VPP, SLOT)\
+ ((((VCC)<<2) | ((VPP)<<0)) << ((SLOT)*8))
static int db1x00_pcmcia_init(struct pcmcia_init *init)
{
@@ -76,7 +87,7 @@
db1x00_pcmcia_socket_state(unsigned sock, struct pcmcia_state *state)
{
u32 inserted;
- unsigned char vs;
+ u16 vs;
if(sock > PCMCIA_MAX_SOCK) return -1;
@@ -87,11 +98,11 @@
if (sock == 0) {
vs = bcsr->status & 0x3;
- inserted = !(bcsr->status & (1<<4));
+ inserted = BOARD_CARD_INSERTED(0);
}
else {
vs = (bcsr->status & 0xC)>>2;
- inserted = !(bcsr->status & (1<<5));
+ inserted = BOARD_CARD_INSERTED(1);
}
DEBUG(KERN_DEBUG "db1x00 socket %d: inserted %d, vs %d\n",
@@ -144,16 +155,9 @@
if(info->sock > PCMCIA_MAX_SOCK) return -1;
if(info->sock == 0)
-#ifdef CONFIG_MIPS_DB1550
- info->irq = AU1000_GPIO_3;
+ info->irq = BOARD_PC0_INT;
else
- info->irq = AU1000_GPIO_5;
-#else
- info->irq = AU1000_GPIO_2;
- else
- info->irq = AU1000_GPIO_5;
-#endif
-
+ info->irq = BOARD_PC1_INT;
return 0;
}
|
@@ -1,6 +1,6 @@
/*
*
- * Alchemy Semi Db1x00 boards specific pcmcia routines.
+ * AMD Alchemy DUAL-SLOT Db1x00 boards' specific pcmcia routines.
*
* Copyright 2002 MontaVista Software Inc.